
The vtool_ibeis_ext Module
==========================

|Pypi| |PypiDownloads| |GithubActions| |Codecov|

Contains the binary spatial verification code used by `vtool_ibeis <https://github.com/Erotemic/vtool_ibeis>`_

This is mainly maintained for the `IBEIS <https://github.com/Erotemic/IBEIS>`_ application.

Binary packages related to IBEIS:

* https://github.com/Erotemic/vtool_ibeis_ext
* https://github.com/Erotemic/pyflann_ibeis
* https://github.com/Erotemic/pyhesaff
 
 
.. |Pypi| image:: https://img.shields.io/pypi/v/vtool_ibeis_ext.svg
    :target: https://pypi.python.org/pypi/vtool_ibeis_ext

.. |PypiDownloads| image:: https://img.shields.io/pypi/dm/vtool_ibeis_ext.svg
    :target: https://pypistats.org/packages/vtool_ibeis_ext

.. |GithubActions| image:: https://github.com/Erotemic/vtool_ibeis_ext/actions/workflows/tests.yml/badge.svg?branch=main
    :target: https://github.com/Erotemic/vtool_ibeis_ext/actions?query=branch%3Amain

.. |Codecov| image:: https://codecov.io/github/Erotemic/vtool_ibeis_ext/badge.svg?branch=main&service=github
    :target: https://codecov.io/github/Erotemic/vtool_ibeis_ext?branch=main

